==> botan-devel_1.7.6.orig.tar.gz: Botan-1.7.6/include/dlies.h <==
/*************************************************
* DLIES Header File                              *
* (C) 1999-2007 Jack Lloyd                       *
*************************************************/

#ifndef BOTAN_DLIES_H__
#define BOTAN_DLIES_H__

#include <botan/pubkey.h>

namespace Botan {

/*************************************************
* DLIES Encryption                               *
*************************************************/
class BOTAN_DLL DLIES_Encryptor : public PK_Encryptor
   {
   public:
      DLIES_Encryptor(const PK_Key_Agreement_Key&,
                      const std::string& = "KDF2(SHA-160)",
                      const std::string& = "HMAC(SHA-160)", u32bit = 20);
      void set_other_key(const MemoryRegion<byte>&);
   private:
      SecureVector<byte> enc(const byte[], u32bit) const;
      u32bit maximum_input_size() const;
      const PK_Key_Agreement_Key& key;
      SecureVector<byte> other_key;
      const std::string kdf_algo;
      const std::string mac_algo;
      const u32bit MAC_KEYLEN;
   };

/*************************************************
* DLIES Decryption                               *
*************************************************/
class BOTAN_DLL DLIES_Decryptor : public PK_Decryptor
   {
   public:
      DLIES_Decryptor(const PK_Key_Agreement_Key&,
                      const std::string& = "KDF2(SHA-160)",
                      const std::string& = "HMAC(SHA-160)", u32bit = 20);
   private:
      SecureVector<byte> dec(const byte[], u32bit) const;
      const PK_Key_Agreement_Key& key;
      const std::string kdf_algo;
      const std::string mac_algo;
      const u32bit MAC_KEYLEN, PUBLIC_LEN;
   };

}

#endif

==> botan-devel_1.7.8.orig.tar.gz: Botan-1.7.8/include/dlies.h <==
/*************************************************
* DLIES Header File                              *
* (C) 1999-2007 Jack Lloyd                       *
*************************************************/

#ifndef BOTAN_DLIES_H__
#define BOTAN_DLIES_H__

#include <botan/pubkey.h>

namespace Botan {

/*************************************************
* DLIES Encryption                               *
*************************************************/
class BOTAN_DLL DLIES_Encryptor : public PK_Encryptor
   {
   public:
      DLIES_Encryptor(const PK_Key_Agreement_Key&,
                      const std::string& = "KDF2(SHA-160)",
                      const std::string& = "HMAC(SHA-160)", u32bit = 20);
      void set_other_key(const MemoryRegion<byte>&);
   private:
      SecureVector<byte> enc(const byte[], u32bit,
                             RandomNumberGenerator&) const;
      u32bit maximum_input_size() const;
      const PK_Key_Agreement_Key& key;
      SecureVector<byte> other_key;
      const std::string kdf_algo;
      const std::string mac_algo;
      const u32bit MAC_KEYLEN;
   };

/*************************************************
* DLIES Decryption                               *
*************************************************/
class BOTAN_DLL DLIES_Decryptor : public PK_Decryptor
   {
   public:
      DLIES_Decryptor(const PK_Key_Agreement_Key&,
                      const std::string& = "KDF2(SHA-160)",
                      const std::string& = "HMAC(SHA-160)", u32bit = 20);
   private:
      SecureVector<byte> dec(const byte[], u32bit) const;
      const PK_Key_Agreement_Key& key;
      const std::string kdf_algo;
      const std::string mac_algo;
      const u32bit MAC_KEYLEN, PUBLIC_LEN;
   };

}

#endif
